==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/sound/SoundEventInit.java <==
package cc.thonly.reverie_dreams.sound;

import cc.thonly.reverie_dreams.Touhou;
import eu.pb4.polymer.core.api.other.PolymerSoundEvent;
import eu.pb4.polymer.rsm.api.RegistrySyncUtils;
import java.util.LinkedList;
import java.util.List;
import java.util.Random;
import net.minecraft.class_1297;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_3414;
import net.minecraft.class_6880;
import net.minecraft.class_7923;

public class SoundEventInit {
    public static final List<class_3414> SOUND_EVENTS = new LinkedList<>();
    public static final class_3414 POINT = registerSound("point");
    public static final class_3414 BIU = registerSound("biu");
    public static final class_3414 SPELL_CARD = registerSound("spell_card");
    public static final class_3414 UP = registerSound("up");
    public static final class_3414 FIRE = registerSound("fire");
    public static final class_3414 BAGUA = registerSound("bagua");
    public static final class_3414 PHOTO = registerSound("photo");
    public static final class_3414 TICK_WAVE = registerSound("tick_wave");
    public static final class_3414 FUMO_0 = registerSound("fumo/0");
    public static final class_3414 FUMO_1 = registerSound("fumo/1");
    public static final class_3414 FUMO_2 = registerSound("fumo/2");
    public static final class_3414 FUMO_3 = registerSound("fumo/3");

    public static final class_3414[] FUMO_SOUNDS = {FUMO_0,FUMO_1,FUMO_2,FUMO_3};

    public static void init() {
    }

    public static class_3414 randomFumo() {
        Random random = new Random();
        int index = random.nextInt(FUMO_SOUNDS.length);
        return FUMO_SOUNDS[index];
    }

    public static class_3414 registerSound(String id) {
        class_2960 identifier = Touhou.id(id);
        class_3414 soundEvent = class_2378.method_10230(class_7923.field_41172, identifier, class_3414.method_47908(identifier));
//        SoundEvent soundEvent = SoundEvent.of(identifier);
        PolymerSoundEvent.registerOverlay(soundEvent);
        SOUND_EVENTS.add(soundEvent);
        return soundEvent;
    }

    protected static class_6880.class_6883<class_3414> registerReference(String id) {
        return registerReference(Touhou.id(id));
    }

    protected static class_6880.class_6883<class_3414> registerReference(class_2960 id) {
        return registerReference(id, id);
    }

    protected static class_6880.class_6883<class_3414> registerReference(class_2960 id, class_2960 soundId) {
        class_3414 soundEvent = class_3414.method_47908(soundId);
        class_6880.class_6883<class_3414> soundEventReference = class_2378.method_47985(class_7923.field_41172, id, soundEvent);
        RegistrySyncUtils.setServerEntry(class_7923.field_41172, soundEvent);
        return soundEventReference;
    }

    public static void playSound(class_1297 entity, class_3414 sound, float volume, float pitch) {
        entity.method_5783(sound, volume, pitch);
    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/sound/SoundEventInit.java <==
package cc.thonly.reverie_dreams.sound;

import cc.thonly.reverie_dreams.ReverieDreams;
import eu.pb4.polymer.core.api.other.PolymerSoundEvent;
import eu.pb4.polymer.rsm.api.RegistrySyncUtils;
import java.util.LinkedList;
import java.util.List;
import java.util.Random;
import net.minecraft.class_1297;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_3414;
import net.minecraft.class_6880;
import net.minecraft.class_7923;

public class SoundEventInit {
    public static final List<class_3414> SOUND_EVENTS = new LinkedList<>();
    public static final class_6880.class_6883<class_3414> EMPTY = registerReference("empty");
    public static final class_3414 POINT = registerSound("point");
    public static final class_3414 BIU = registerSound("biu");
    public static final class_3414 SPELL_CARD = registerSound("spell_card");
    public static final class_3414 UP = registerSound("up");
    public static final class_3414 FIRE = registerSound("fire");
    public static final class_3414 BAGUA = registerSound("bagua");
    public static final class_3414 PHOTO = registerSound("photo");
    public static final class_3414 TICK_WAVE = registerSound("tick_wave");
    public static final class_3414 GRAZE = registerSound("graze");
    public static final class_3414 FUMO_0 = registerSound("fumo/0");
    public static final class_3414 FUMO_1 = registerSound("fumo/1");
    public static final class_3414 FUMO_2 = registerSound("fumo/2");
    public static final class_3414 FUMO_3 = registerSound("fumo/3");

    public static final class_3414[] FUMO_SOUNDS = {FUMO_0,FUMO_1,FUMO_2,FUMO_3};

    public static void init() {
    }

    public static class_3414 randomFumo() {
        Random random = new Random();
        int index = random.nextInt(FUMO_SOUNDS.length);
        return FUMO_SOUNDS[index];
    }

    public static class_3414 registerSound(String id) {
        class_2960 identifier = ReverieDreams.id(id);
        class_3414 soundEvent = class_2378.method_10230(class_7923.field_41172, identifier, class_3414.method_47908(identifier));
//        SoundEvent soundEvent = SoundEvent.of(identifier);
        PolymerSoundEvent.registerOverlay(soundEvent);
        SOUND_EVENTS.add(soundEvent);
        return soundEvent;
    }

    protected static class_6880.class_6883<class_3414> registerReference(String id) {
        return registerReference(ReverieDreams.id(id));
    }

    protected static class_6880.class_6883<class_3414> registerReference(class_2960 id) {
        return registerReference(id, id);
    }

    protected static class_6880.class_6883<class_3414> registerReference(class_2960 id, class_2960 soundId) {
        class_3414 soundEvent = class_3414.method_47908(soundId);
        class_6880.class_6883<class_3414> soundEventReference = class_2378.method_47985(class_7923.field_41172, id, soundEvent);
        RegistrySyncUtils.setServerEntry(class_7923.field_41172, soundEvent);
        return soundEventReference;
    }

    public static void playSound(class_1297 entity, class_3414 sound, float volume, float pitch) {
        entity.method_5783(sound, volume, pitch);
    }
}
